@@ -25,21 +25,18 @@
 
 class QgsCoordinateReferenceSystem;
 
-#if PROJ_VERSION_MAJOR>=6
 #ifndef SIP_RUN
 struct PJconsts;
 typedef struct PJconsts PJ;
 #endif
-#endif
 
 /**
- * Contains methods and classes relating the datum transformations.
+ * \brief Contains methods and classes relating the datum transformations.
  * \ingroup core
  *
  * \see QgsCoordinateTransformContext
  * \see QgsCoordinateTransform
  *
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsDatumTransform
 {
@@ -48,8 +45,7 @@ class CORE_EXPORT QgsDatumTransform
 
     /**
      * Contains datum transform information.
-     * \deprecated Not used for builds based on Proj >= 6.0
-     * \since QGIS 3.0
+     * \deprecated QGIS 3.40. Not used for builds based on Proj >= 6.0.
      */
     struct TransformPair
     {
@@ -75,6 +71,7 @@ class CORE_EXPORT QgsDatumTransform
        */
       int destinationTransformId = -1;
 
+      // TODO c++20 - replace with = default
       bool operator==( QgsDatumTransform::TransformPair other ) const
       {
         return other.sourceTransformId == sourceTransformId && other.destinationTransformId == destinationTransformId;
@@ -89,7 +86,7 @@ class CORE_EXPORT QgsDatumTransform
 
     /**
      * Contains datum transform information.
-     * \deprecated Not used on builds based on Proj >= 6.0
+     * \deprecated QGIS 3.40. Not used on builds based on Proj >= 6.0.
      */
     struct TransformInfo
     {
@@ -283,7 +280,7 @@ class CORE_EXPORT QgsDatumTransform
      * \see datumTransformToProj()
      * \see datumTransformInfo()
      *
-     * \deprecated Not used for builds based on Proj >= 6.0
+     * \deprecated QGIS 3.40. Not used for builds based on Proj >= 6.0.
      */
     Q_DECL_DEPRECATED static QList< QgsDatumTransform::TransformPair > datumTransformations( const QgsCoordinateReferenceSystem &source, const QgsCoordinateReferenceSystem &destination ) SIP_DEPRECATED;
 
@@ -293,7 +290,7 @@ class CORE_EXPORT QgsDatumTransform
      * \see datumTransformInfo()
      * \see projStringToDatumTransformId()
      *
-     * \deprecated Not used for builds based on Proj >= 6.0
+     * \deprecated QGIS 3.40. Not used for builds based on Proj >= 6.0.
      */
     Q_DECL_DEPRECATED static QString datumTransformToProj( int datumTransformId ) SIP_DEPRECATED;
 
@@ -302,7 +299,7 @@ class CORE_EXPORT QgsDatumTransform
      * Returns -1 if matching datum ID was not found.
      * \see datumTransformToProj()
      *
-     * \deprecated Not used for builds based on Proj >= 6.0
+     * \deprecated QGIS 3.40. Not used for builds based on Proj >= 6.0.
      */
     Q_DECL_DEPRECATED static int projStringToDatumTransformId( const QString &string ) SIP_DEPRECATED;
 
@@ -313,12 +310,11 @@ class CORE_EXPORT QgsDatumTransform
      * \see datumTransformations()
      * \see datumTransformToProj()
      *
-     * \deprecated Not used for builds based on Proj >= 6.0
+     * \deprecated QGIS 3.40. Not used for builds based on Proj >= 6.0.
     */
     Q_DECL_DEPRECATED static QgsDatumTransform::TransformInfo datumTransformInfo( int datumTransformId ) SIP_DEPRECATED;
 
 #ifndef SIP_RUN
-#if PROJ_VERSION_MAJOR >= 6
 
     /**
      * Returns the transform details for a Proj coordinate operation \a op.
@@ -327,7 +323,6 @@ class CORE_EXPORT QgsDatumTransform
      * \since QGIS 3.8
      */
     static QgsDatumTransform::TransformDetails transformDetailsFromPj( PJ *op );
-#endif
 #endif
 
   private:
